@@ -1,7 +1,7 @@
 library(testthat)
 library(tidyLPA)
 options("test_mplus" = FALSE)
-if(file.exists("tests/test_local.R")) source("tests/test_local.R")
+if(file.exists("test_local.R")) source("test_local.R")
 # To run all mplus tests, run the code below once to create a file that is not
 # tracked by git, which toggles the option to run mplus tests:
 # writeLines('options("test_mplus" = TRUE)', con = "tests/test_local.R")
